---
title: Supported Networks
description: All the public networks the Ocean Protocol contracts are deployed to.
---

# Networks

Ocean Protocol contracts are deployed on multiple public networks. You can always find the most up-to-date deployment addresses for all individual contracts in the [address.json](https://github.com/oceanprotocol/contracts/blob/v4main/addresses/address.json).

In each network, whether it's the Ethereum mainnet, a testnet, or the Polygon/Matic network, you'll need ETH or Matic to pay for gas and OCEAN for certain actions on the Ocean Protocol network. The Ethereum mainnet and the Polygon network are both live networks and the tokens on these networks have real value. However, the tokens on the test networks are not of real value and are only used for testing purposes. You can obtain testnet ETH and OCEAN tokens from faucets, which are services that provide small amounts of tokens for free.

### Ethereum Mainnet

The Ethereum mainnet is a production network, which means that it is a live and operational network that handles real transactions and has actual economic value. To connect to the Ethereum mainnet using a wallet such as MetaMask, you can click on the network name dropdown and select Ethereum mainnet from the list of available networks.

| Gas Token   | Mainnet ETH (Native token)                                                                                           |
| ----------- | -------------------------------------------------------------------------------------------------------------------- |
| OCEAN Token |  [0x967da4048cD07aB37855c090aAF366e4ce1b9F48](https://etherscan.io/token/0x967da4048cD07aB37855c090aAF366e4ce1b9F48) |
| Explorer    | [https://etherscan.io](https://etherscan.io)                                                                         |

### Polygon Mainnet

Ocean Protocol is also deployed to Polygon Mainnet, which is another production network. The native token of Polygon Mainnet is MATIC. If you cannot find Polygon Mainnet as a predefined network in your wallet, you can manually connect to it by following Polygon's [guide](https://wiki.polygon.technology/docs/develop/metamask/config-polygon-on-metamask/#add-the-polygon-network-manually), which provides step-by-step instructions for connecting to Polygon Mainnet.

| Gas Token | Matic(Native token)                                                                                                    |
| --------- | ---------------------------------------------------------------------------------------------------------------------- |
| OCEAN     | [0x282d8efCe846A88B159800bd4130ad77443Fa1A1](https://polygonscan.com/token/0x282d8efce846a88b159800bd4130ad77443fa1a1) |
| Explorer  | [https://polygonscan.com](https://polygonscan.com)                                                                     |

**Bridge**

Check our Polygon Bridge [guide](bridges.md) to learn how you can deposit, withdraw and send tokens.

### Binance Smart Chain

Ocean Protocol is also deployed to Binance Smart Chain (BSC), which is another production network. The native token of the Binance Smart Chain is BNB, which is the token of the Binance exchange. If Binance Smart Chain is not listed as a predefined network in your wallet, you can manually connect to it by following Binance's [guide](https://academy.binance.com/en/articles/connecting-metamask-to-binance-smart-chain), which provides detailed instructions on how to connect to Binance Smart Chain.

| Gas Token | BSC BNB(Native token)                                                                                              |
| --------- | ------------------------------------------------------------------------------------------------------------------ |
| OCEAN     | [0xdce07662ca8ebc241316a15b611c89711414dd1a](https://bscscan.com/token/0xdce07662ca8ebc241316a15b611c89711414dd1a) |
| Explorer  | [https://bscscan.com/](https://bscscan.com/)                                                                       |

**Bridge**

Check our BSC Bridge [guide](../../core-concepts/networks/bridges.md#binance-smart-chain-bsc-bridge) to learn how you can deposit, withdraw and send tokens.

### Energy Web Chain

Ocean Protocol is also deployed to [Energy Web Chain](https://energy-web-foundation.gitbook.io/energy-web/technology/trust-layer-energy-web-chain), which is another production network. The native token of the Energy Web Chain is EWT. If you cannot find Energy Web Chain as a predefined network in your wallet, you can manually connect to it by following this [guide](https://energy-web-foundation.gitbook.io/energy-web/how-tos-and-tutorials/connect-to-energy-web-chain-main-network-with-metamash).

| Gas Token | Energy Web Chain EWT(Native token)                                                                                            |
| --------- | ----------------------------------------------------------------------------------------------------------------------------- |
| OCEAN     | [0x593122aae80a6fc3183b2ac0c4ab3336debee528](https://explorer.energyweb.org/token/0x593122aae80a6fc3183b2ac0c4ab3336debee528) |
| Explorer  | [https://explorer.energyweb.org/](https://explorer.energyweb.org/)                                                            |

**Bridge**

To bridge assets between Energy Web Chain and Ethereum mainnet, you can use [this](https://bridge.carbonswap.exchange/) bridge.

### Moonriver

Ocean Protocol is also deployed to [Moonriver](https://docs.moonbeam.network/builders/get-started/networks/moonriver/), which is another production network. The native token of Moonriver is MOVR. If Moonriver is not listed as a predefined network in your wallet, you can manually connect to it by following this [guide](https://docs.moonbeam.network/builders/get-started/networks/moonriver/#connect-metamask).

| Gas Token | Moonriver MOVR(Native token)                                                                                                                                 |
| --------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| OCEAN     | [0x99C409E5f62E4bd2AC142f17caFb6810B8F0BAAE](https://blockscout.moonriver.moonbeam.network/token/0x99C409E5f62E4bd2AC142f17caFb6810B8F0BAAE/token-transfers) |
| Explorer  | [https://blockscout.moonriver.moonbeam.network](https://blockscout.moonriver.moonbeam.network)                                                               |

**Bridge**

To bridge assets between Moonriver and Ethereum mainnet, you can use [this](https://anyswap.exchange/#/bridge) bridge.

### Görli

Ocean Protocol is deployed on the Görli test network, which is used for testing and experimentation. Tokens on Görli do not hold real economic value, as it is a non-production network. To connect to Görli using a wallet like MetaMask, simply click on the network name dropdown and select _Goerli_ from the list of available networks.

| Gas Token   | Görli ETH(Native token)                                                                                                                                  |
| ----------- | -------------------------------------------------------------------------------------------------------------------------------------------------------- |
| Görli ETH   | [Faucet](https://goerlifaucet.com/). You may find others by [searching](https://www.google.com/search?q=goerli+ether+faucet%5C\&oq=goerli+ether+faucet). |
| OCEAN       | [0xCfDdA22C9837aE76E0faA845354f33C62E03653a](https://goerli.etherscan.io/address/0xcfdda22c9837ae76e0faa845354f33c62e03653a)                             |
| Görli OCEAN | [Faucet](https://faucet.goerli.oceanprotocol.com)                                                                                                        |
| Explorer    | [https://blockscout.moonriver.moonbeam.network](https://blockscout.moonriver.moonbeam.network)                                                           |

### Mumbai

Ocean Protocol is deployed on the Mumbai test network Matic / Polygon, which is designed for testing and experimentation purposes. Tokens in Mumbai do not hold any real economic value, as it is not a production network. To connect to Mumbai using a wallet like MetaMask, you can select "Görli" from the network dropdown list.

If Mumbai is not listed as a predefined network in your wallet, you can connect to it manually by following [Matic's guide](https://wiki.polygon.technology/docs/develop/metamask/config-polygon-on-metamask/).

| Gas Token    | Mumbai MATIC(Native token)                                                                                                    |
| ------------ | ----------------------------------------------------------------------------------------------------------------------------- |
| Mumbai MATIC | [Faucet](https://faucet.matic.network/). You may find others by [searching](https://www.google.com/search?q=mumbai+faucet).   |
| OCEAN        | [0xd8992Ed72C445c35Cb4A2be468568Ed1079357c8](https://mumbai.polygonscan.com/token/0xd8992Ed72C445c35Cb4A2be468568Ed1079357c8) |
| Mumbai OCEAN | [Faucet](https://faucet.mumbai.oceanprotocol.com/)                                                                            |
| Explorer     | [https://mumbai.polygonscan.com](https://mumbai.polygonscan.com)                                                              |

### Local / Ganache

The most straightforward way for local-only development is to use [Barge](https://www.github.com/oceanprotocol/barge), which runs [Ganache](https://www.trufflesuite.com/ganache), Aquarius, and Provider. It is used extensively by the Ocean core devs and for automated integration testing.

To connect to it from MetaMask, select the network called _Localhost 8545_.

Alternatively, you can run Ganache independently. Install it according to [the Ganache docs](https://www.trufflesuite.com/ganache). Then deploy Ocean contracts onto Ganache following [docs in Ocean contracts repo](https://www.github.com/oceanprotocol/contracts). Ganache is at the RPC URL [http://localhost:8545](http://localhost:8545).

**Tokens**

* Ganache ETH:
  * Native token to pay transaction fees
  * By default, Ganache creates several Ethereum accounts at launch, gives each some ETH, and makes their private keys available in the logs. You can also instruct Ganache to give ETH to specific Ethereum addresses.
* Ganache OCEAN:
  * You can deploy an ERC20 token with the label OCEAN. At a minimum, the token needs to be ERC20Detailed and ERC20Capped. You’ll see examples in the quickstarts for the Ocean JavaScript and Python drivers.

### Other

Some apps may need `network_id` and `chain_id`. Here's a [list of values for major Ethereum networks](https://medium.com/@piyopiyo/list-of-ethereums-major-network-and-chain-ids-2bc58e928508).
